# WLabKit
**This is a toolkit to handle bio-data from WeiBin Lab.**

![WLabKit](https://cdn.jsdelivr.net/gh/BioGavin/Pic/imgWLabKit.png)

Similar data processing tasks occur frequently in my daily work though these tasks are not complicated. To avoid change the code repeatedly, I set up this project for the convenience of laboratory members and others.

## Installation
Binary installers for the latest released version are available at the Python Package Index (PyPI) and on Conda.
```shell
conda install wlabkit
```
```shell
pip install wlabkit
```

## Help
Get help information, you can run:
```shell
wlabkit -h
```

If you want to get help information of subcommand, you can run:
```shell
wlabkit [subcommand] -h
```

## Subcommands
Subcommands are as follows

- ***getseq***

get target sequences from a header list.

## Contact
If you have any problems, don't hesitate to contact me. <gavinchou64@gmail.com>


